==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/confidentialledger/kotlin/inputs/LedgerPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.confidentialledger.kotlin.inputs

import com.pulumi.azurenative.confidentialledger.inputs.LedgerPropertiesArgs.builder
import com.pulumi.azurenative.confidentialledger.kotlin.enums.LedgerType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Additional Confidential Ledger properties.
 * @property aadBasedSecurityPrincipals Array of all AAD based Security Principals.
 * @property certBasedSecurityPrincipals Array of all cert based Security Principals.
 * @property ledgerType Type of Confidential Ledger
 */
public data class LedgerPropertiesArgs(
    public val aadBasedSecurityPrincipals: Output<List<AADBasedSecurityPrincipalArgs>>? = null,
    public val certBasedSecurityPrincipals: Output<List<CertBasedSecurityPrincipalArgs>>? = null,
    public val ledgerType: Output<Either<String, LedgerType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.confidentialledger.inputs.LedgerPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.confidentialledger.inputs.LedgerPropertiesArgs =
        com.pulumi.azurenative.confidentialledger.inputs.LedgerPropertiesArgs.builder()
            .aadBasedSecurityPrincipals(
                aadBasedSecurityPrincipals?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .certBasedSecurityPrincipals(
                certBasedSecurityPrincipals?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ledgerType(
                ledgerType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [LedgerPropertiesArgs].
 */
@PulumiTagMarker
public class LedgerPropertiesArgsBuilder internal constructor() {
    private var aadBasedSecurityPrincipals: Output<List<AADBasedSecurityPrincipalArgs>>? = null

    private var certBasedSecurityPrincipals: Output<List<CertBasedSecurityPrincipalArgs>>? = null

    private var ledgerType: Output<Either<String, LedgerType>>? = null

    /**
     * @param value Array of all AAD based Security Principals.
     */
    @JvmName("vefsuwodplhkidea")
    public suspend
    fun aadBasedSecurityPrincipals(`value`: Output<List<AADBasedSecurityPrincipalArgs>>) {
        this.aadBasedSecurityPrincipals = value
    }

    @JvmName("pmxalsjrdqbvryqm")
    public suspend fun aadBasedSecurityPrincipals(
        vararg
        values: Output<AADBasedSecurityPrincipalArgs>,
    ) {
        this.aadBasedSecurityPrincipals = Output.all(values.asList())
    }

    /**
     * @param values Array of all AAD based Security Principals.
     */
    @JvmName("asawfcklxifoeija")
    public suspend
    fun aadBasedSecurityPrincipals(values: List<Output<AADBasedSecurityPrincipalArgs>>) {
        this.aadBasedSecurityPrincipals = Output.all(values)
    }

    /**
     * @param value Array of all cert based Security Principals.
     */
    @JvmName("atqoeoqlmfolpddc")
    public suspend
    fun certBasedSecurityPrincipals(`value`: Output<List<CertBasedSecurityPrincipalArgs>>) {
        this.certBasedSecurityPrincipals = value
    }

    @JvmName("evrxswkawwrsbtlk")
    public suspend fun certBasedSecurityPrincipals(
        vararg
        values: Output<CertBasedSecurityPrincipalArgs>,
    ) {
        this.certBasedSecurityPrincipals = Output.all(values.asList())
    }

    /**
     * @param values Array of all cert based Security Principals.
     */
    @JvmName("kjvrvjdmtnhmsymn")
    public suspend
    fun certBasedSecurityPrincipals(values: List<Output<CertBasedSecurityPrincipalArgs>>) {
        this.certBasedSecurityPrincipals = Output.all(values)
    }

    /**
     * @param value Type of Confidential Ledger
     */
    @JvmName("ycrnmeitlvgshyqs")
    public suspend fun ledgerType(`value`: Output<Either<String, LedgerType>>) {
        this.ledgerType = value
    }

    /**
     * @param value Array of all AAD based Security Principals.
     */
    @JvmName("syuiyopqimxkkfjp")
    public suspend fun aadBasedSecurityPrincipals(`value`: List<AADBasedSecurityPrincipalArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.aadBasedSecurityPrincipals = mapped
    }

    /**
     * @param argument Array of all AAD based Security Principals.
     */
    @JvmName("hwcfeqsuhthtlkah")
    public suspend
    fun aadBasedSecurityPrincipals(argument: List<suspend AADBasedSecurityPrincipalArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AADBasedSecurityPrincipalArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.aadBasedSecurityPrincipals = mapped
    }

    /**
     * @param argument Array of all AAD based Security Principals.
     */
    @JvmName("hceaarqohbufvatv")
    public suspend fun aadBasedSecurityPrincipals(
        vararg
        argument: suspend AADBasedSecurityPrincipalArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            AADBasedSecurityPrincipalArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.aadBasedSecurityPrincipals = mapped
    }

    /**
     * @param argument Array of all AAD based Security Principals.
     */
    @JvmName("tqmholmgmcqehnjs")
    public suspend
    fun aadBasedSecurityPrincipals(argument: suspend AADBasedSecurityPrincipalArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            AADBasedSecurityPrincipalArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.aadBasedSecurityPrincipals = mapped
    }

    /**
     * @param values Array of all AAD based Security Principals.
     */
    @JvmName("qduupelpxtsaltru")
    public suspend fun aadBasedSecurityPrincipals(vararg values: AADBasedSecurityPrincipalArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.aadBasedSecurityPrincipals = mapped
    }

    /**
     * @param value Array of all cert based Security Principals.
     */
    @JvmName("cytsacwedkhsmnbw")
    public suspend fun certBasedSecurityPrincipals(`value`: List<CertBasedSecurityPrincipalArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.certBasedSecurityPrincipals = mapped
    }

    /**
     * @param argument Array of all cert based Security Principals.
     */
    @JvmName("nuymjqvpdubkmiht")
    public suspend
    fun certBasedSecurityPrincipals(argument: List<suspend CertBasedSecurityPrincipalArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            CertBasedSecurityPrincipalArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.certBasedSecurityPrincipals = mapped
    }

    /**
     * @param argument Array of all cert based Security Principals.
     */
    @JvmName("ofuolcjhahjruakh")
    public suspend fun certBasedSecurityPrincipals(
        vararg
        argument: suspend CertBasedSecurityPrincipalArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            CertBasedSecurityPrincipalArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.certBasedSecurityPrincipals = mapped
    }

    /**
     * @param argument Array of all cert based Security Principals.
     */
    @JvmName("stgojraljmpsxohm")
    public suspend
    fun certBasedSecurityPrincipals(argument: suspend CertBasedSecurityPrincipalArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            CertBasedSecurityPrincipalArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.certBasedSecurityPrincipals = mapped
    }

    /**
     * @param values Array of all cert based Security Principals.
     */
    @JvmName("umqtpbwjgvjmebkm")
    public suspend fun certBasedSecurityPrincipals(vararg values: CertBasedSecurityPrincipalArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certBasedSecurityPrincipals = mapped
    }

    /**
     * @param value Type of Confidential Ledger
     */
    @JvmName("nayqhqdwsbouuctk")
    public suspend fun ledgerType(`value`: Either<String, LedgerType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ledgerType = mapped
    }

    /**
     * @param value Type of Confidential Ledger
     */
    @JvmName("npdbvljcjbbgqann")
    public fun ledgerType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LedgerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ledgerType = mapped
    }

    /**
     * @param value Type of Confidential Ledger
     */
    @JvmName("jwtabxewssavmmvb")
    public fun ledgerType(`value`: LedgerType) {
        val toBeMapped = Either.ofRight<String, LedgerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ledgerType = mapped
    }

    internal fun build(): LedgerPropertiesArgs = LedgerPropertiesArgs(
        aadBasedSecurityPrincipals = aadBasedSecurityPrincipals,
        certBasedSecurityPrincipals = certBasedSecurityPrincipals,
        ledgerType = ledgerType,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/confidentialledger/kotlin/inputs/LedgerPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.confidentialledger.kotlin.inputs

import com.pulumi.azurenative.confidentialledger.inputs.LedgerPropertiesArgs.builder
import com.pulumi.azurenative.confidentialledger.kotlin.enums.LedgerType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Additional Confidential Ledger properties.
 * @property aadBasedSecurityPrincipals Array of all AAD based Security Principals.
 * @property certBasedSecurityPrincipals Array of all cert based Security Principals.
 * @property ledgerType Type of Confidential Ledger
 */
public data class LedgerPropertiesArgs(
    public val aadBasedSecurityPrincipals: Output<List<AADBasedSecurityPrincipalArgs>>? = null,
    public val certBasedSecurityPrincipals: Output<List<CertBasedSecurityPrincipalArgs>>? = null,
    public val ledgerType: Output<Either<String, LedgerType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.confidentialledger.inputs.LedgerPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.confidentialledger.inputs.LedgerPropertiesArgs =
        com.pulumi.azurenative.confidentialledger.inputs.LedgerPropertiesArgs.builder()
            .aadBasedSecurityPrincipals(
                aadBasedSecurityPrincipals?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .certBasedSecurityPrincipals(
                certBasedSecurityPrincipals?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .ledgerType(
                ledgerType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [LedgerPropertiesArgs].
 */
@PulumiTagMarker
public class LedgerPropertiesArgsBuilder internal constructor() {
    private var aadBasedSecurityPrincipals: Output<List<AADBasedSecurityPrincipalArgs>>? = null

    private var certBasedSecurityPrincipals: Output<List<CertBasedSecurityPrincipalArgs>>? = null

    private var ledgerType: Output<Either<String, LedgerType>>? = null

    /**
     * @param value Array of all AAD based Security Principals.
     */
    @JvmName("qgiaqmucykoahuqp")
    public suspend
    fun aadBasedSecurityPrincipals(`value`: Output<List<AADBasedSecurityPrincipalArgs>>) {
        this.aadBasedSecurityPrincipals = value
    }

    @JvmName("ikwlqdkwoysjbmlj")
    public suspend fun aadBasedSecurityPrincipals(
        vararg
        values: Output<AADBasedSecurityPrincipalArgs>,
    ) {
        this.aadBasedSecurityPrincipals = Output.all(values.asList())
    }

    /**
     * @param values Array of all AAD based Security Principals.
     */
    @JvmName("oxhspnafyrnbiqpe")
    public suspend
    fun aadBasedSecurityPrincipals(values: List<Output<AADBasedSecurityPrincipalArgs>>) {
        this.aadBasedSecurityPrincipals = Output.all(values)
    }

    /**
     * @param value Array of all cert based Security Principals.
     */
    @JvmName("btdvccnohymjurrt")
    public suspend
    fun certBasedSecurityPrincipals(`value`: Output<List<CertBasedSecurityPrincipalArgs>>) {
        this.certBasedSecurityPrincipals = value
    }

    @JvmName("cadnmswifnovfrmw")
    public suspend fun certBasedSecurityPrincipals(
        vararg
        values: Output<CertBasedSecurityPrincipalArgs>,
    ) {
        this.certBasedSecurityPrincipals = Output.all(values.asList())
    }

    /**
     * @param values Array of all cert based Security Principals.
     */
    @JvmName("djfrxanhuqchuprv")
    public suspend
    fun certBasedSecurityPrincipals(values: List<Output<CertBasedSecurityPrincipalArgs>>) {
        this.certBasedSecurityPrincipals = Output.all(values)
    }

    /**
     * @param value Type of Confidential Ledger
     */
    @JvmName("kpjrnxkxspcyiduk")
    public suspend fun ledgerType(`value`: Output<Either<String, LedgerType>>) {
        this.ledgerType = value
    }

    /**
     * @param value Array of all AAD based Security Principals.
     */
    @JvmName("xclsqvxwakhshwvv")
    public suspend fun aadBasedSecurityPrincipals(`value`: List<AADBasedSecurityPrincipalArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.aadBasedSecurityPrincipals = mapped
    }

    /**
     * @param argument Array of all AAD based Security Principals.
     */
    @JvmName("adkmgpposshxnpwe")
    public suspend
    fun aadBasedSecurityPrincipals(argument: List<suspend AADBasedSecurityPrincipalArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AADBasedSecurityPrincipalArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.aadBasedSecurityPrincipals = mapped
    }

    /**
     * @param argument Array of all AAD based Security Principals.
     */
    @JvmName("rnatvkmhodnsuolv")
    public suspend fun aadBasedSecurityPrincipals(
        vararg
        argument: suspend AADBasedSecurityPrincipalArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            AADBasedSecurityPrincipalArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.aadBasedSecurityPrincipals = mapped
    }

    /**
     * @param argument Array of all AAD based Security Principals.
     */
    @JvmName("bpyxoirwiyceemre")
    public suspend
    fun aadBasedSecurityPrincipals(argument: suspend AADBasedSecurityPrincipalArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            AADBasedSecurityPrincipalArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.aadBasedSecurityPrincipals = mapped
    }

    /**
     * @param values Array of all AAD based Security Principals.
     */
    @JvmName("hiyhgjikbtprfgek")
    public suspend fun aadBasedSecurityPrincipals(vararg values: AADBasedSecurityPrincipalArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.aadBasedSecurityPrincipals = mapped
    }

    /**
     * @param value Array of all cert based Security Principals.
     */
    @JvmName("bjiuxilnvxkkjkpf")
    public suspend fun certBasedSecurityPrincipals(`value`: List<CertBasedSecurityPrincipalArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.certBasedSecurityPrincipals = mapped
    }

    /**
     * @param argument Array of all cert based Security Principals.
     */
    @JvmName("yrubiisoqipruibo")
    public suspend
    fun certBasedSecurityPrincipals(argument: List<suspend CertBasedSecurityPrincipalArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            CertBasedSecurityPrincipalArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.certBasedSecurityPrincipals = mapped
    }

    /**
     * @param argument Array of all cert based Security Principals.
     */
    @JvmName("hsoatitntnobkamy")
    public suspend fun certBasedSecurityPrincipals(
        vararg
        argument: suspend CertBasedSecurityPrincipalArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            CertBasedSecurityPrincipalArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.certBasedSecurityPrincipals = mapped
    }

    /**
     * @param argument Array of all cert based Security Principals.
     */
    @JvmName("svwyonhctxqdqclh")
    public suspend
    fun certBasedSecurityPrincipals(argument: suspend CertBasedSecurityPrincipalArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            CertBasedSecurityPrincipalArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.certBasedSecurityPrincipals = mapped
    }

    /**
     * @param values Array of all cert based Security Principals.
     */
    @JvmName("hujwcmdqpakldjnn")
    public suspend fun certBasedSecurityPrincipals(vararg values: CertBasedSecurityPrincipalArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.certBasedSecurityPrincipals = mapped
    }

    /**
     * @param value Type of Confidential Ledger
     */
    @JvmName("tofegpafxxojjjga")
    public suspend fun ledgerType(`value`: Either<String, LedgerType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ledgerType = mapped
    }

    /**
     * @param value Type of Confidential Ledger
     */
    @JvmName("hsktccqrteflrypp")
    public fun ledgerType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, LedgerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ledgerType = mapped
    }

    /**
     * @param value Type of Confidential Ledger
     */
    @JvmName("yilgswxqfsfhhqyu")
    public fun ledgerType(`value`: LedgerType) {
        val toBeMapped = Either.ofRight<String, LedgerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.ledgerType = mapped
    }

    internal fun build(): LedgerPropertiesArgs = LedgerPropertiesArgs(
        aadBasedSecurityPrincipals = aadBasedSecurityPrincipals,
        certBasedSecurityPrincipals = certBasedSecurityPrincipals,
        ledgerType = ledgerType,
    )
}
